@@ -431,30 +431,63 @@ func compileCallExpr(ctx *blockCtx, v *ast.CallExpr, flags int) {
 	fnt := ctx.cb.Get(-1).Type
 	ellipsis := (v.Ellipsis != gotoken.NoPos)
 	for i, arg := range v.Args {
-		if l, ok := arg.(*ast.LambdaExpr); ok {
-			fn.initWith(fnt, i, len(l.Lhs))
-			if sig, ok := fn.arg(i, true).(*types.Signature); ok {
-				compileLambdaExpr(ctx, l, sig.Params())
-				continue
-			}
-		}
-		if l, ok := arg.(*ast.LambdaExpr2); ok {
-			fn.initWith(fnt, i, len(l.Lhs))
-			if sig, ok := fn.arg(i, true).(*types.Signature); ok {
-				compileLambdaExpr2(ctx, l, sig.Params())
-				continue
-			}
-		}
-		if c, ok := arg.(*ast.CompositeLit); ok && c.Type == nil {
+		switch expr := arg.(type) {
+		case *ast.LambdaExpr:
+			fn.initWith(fnt, i, len(expr.Lhs))
+			sig := checkLambdaFuncType(ctx, expr, fn.arg(i, true), clLambaArgument, v.Fun)
+			compileLambdaExpr(ctx, expr, sig)
+		case *ast.LambdaExpr2:
+			fn.initWith(fnt, i, len(expr.Lhs))
+			sig := checkLambdaFuncType(ctx, expr, fn.arg(i, true), clLambaArgument, v.Fun)
+			compileLambdaExpr2(ctx, expr, sig)
+		case *ast.CompositeLit:
 			fn.initWith(fnt, i, -1)
-			compileCompositeLit(ctx, c, fn.arg(i, ellipsis), true)
-		} else {
+			compileCompositeLit(ctx, expr, fn.arg(i, ellipsis), true)
+		default:
 			compileExpr(ctx, arg)
 		}
 	}
 	ctx.cb.CallWith(len(v.Args), ellipsis, v)
 }
 
+type clLambaFlag string
+
+const (
+	clLambaAssign   clLambaFlag = "assignment"
+	clLambaField    clLambaFlag = "field value"
+	clLambaArgument clLambaFlag = "argument"
+)
+
+// check lambda func type
+func checkLambdaFuncType(ctx *blockCtx, lambda ast.Expr, ftyp types.Type, flag clLambaFlag, toNode ast.Node) *types.Signature {
+	typ := ftyp
+retry:
+	switch t := typ.(type) {
+	case *types.Signature:
+		if l, ok := lambda.(*ast.LambdaExpr); ok {
+			if len(l.Rhs) != t.Results().Len() {
+				break
+			}
+		}
+		return t
+	case *types.Named:
+		typ = t.Underlying()
+		goto retry
+	}
+	src, _ := ctx.LoadExpr(toNode)
+	err := ctx.newCodeErrorf(lambda.Pos(), "cannot use lambda literal as type %v in %v to %v", ftyp, flag, src)
+	panic(err)
+}
+
+func compileLambda(ctx *blockCtx, lambda ast.Expr, sig *types.Signature) {
+	switch expr := lambda.(type) {
+	case *ast.LambdaExpr:
+		compileLambdaExpr(ctx, expr, sig)
+	case *ast.LambdaExpr2:
+		compileLambdaExpr2(ctx, expr, sig)
+	}
+}
+
 func compileLambdaParams(ctx *blockCtx, pos token.Pos, lhs []*ast.Ident, in *types.Tuple) []*types.Var {
 	pkg := ctx.pkg
 	n := len(lhs)
@@ -477,13 +510,14 @@ func compileLambdaParams(ctx *blockCtx, pos token.Pos, lhs []*ast.Ident, in *typ
 	return params
 }
 
-func compileLambdaExpr(ctx *blockCtx, v *ast.LambdaExpr, in *types.Tuple) {
+func compileLambdaExpr(ctx *blockCtx, v *ast.LambdaExpr, sig *types.Signature) {
 	pkg := ctx.pkg
-	params := compileLambdaParams(ctx, v.Pos(), v.Lhs, in)
-	nout := len(v.Rhs)
+	params := compileLambdaParams(ctx, v.Pos(), v.Lhs, sig.Params())
+	out := sig.Results()
+	nout := out.Len()
 	results := make([]*types.Var, nout)
 	for i := 0; i < nout; i++ {
-		results[i] = pkg.NewAutoParam("")
+		results[i] = pkg.NewParam(token.NoPos, "", out.At(i).Type())
 	}
 	ctx.cb.NewClosure(types.NewTuple(params...), types.NewTuple(results...), false).BodyStart(pkg)
 	for _, v := range v.Rhs {
@@ -492,11 +526,18 @@ func compileLambdaExpr(ctx *blockCtx, v *ast.LambdaExpr, in *types.Tuple) {
 	ctx.cb.Return(nout).End()
 }
 
-func compileLambdaExpr2(ctx *blockCtx, v *ast.LambdaExpr2, in *types.Tuple) {
-	params := compileLambdaParams(ctx, v.Pos(), v.Lhs, in)
+func compileLambdaExpr2(ctx *blockCtx, v *ast.LambdaExpr2, sig *types.Signature) {
+	pkg := ctx.pkg
+	params := compileLambdaParams(ctx, v.Pos(), v.Lhs, sig.Params())
 	cb := ctx.cb
 	comments := cb.Comments()
-	fn := cb.NewClosure(types.NewTuple(params...), nil, false)
+	out := sig.Results()
+	nout := out.Len()
+	results := make([]*types.Var, nout)
+	for i := 0; i < nout; i++ {
+		results[i] = pkg.NewParam(token.NoPos, "", out.At(i).Type())
+	}
+	fn := cb.NewClosure(types.NewTuple(params...), types.NewTuple(results...), false)
 	loadFuncBody(ctx, fn, v.Body)
 	cb.SetComments(comments, false)
 }
@@ -566,12 +607,19 @@ func compileStructLitInKeyVal(ctx *blockCtx, elts []ast.Expr, t *types.Struct, t
 	for _, elt := range elts {
 		kv := elt.(*ast.KeyValueExpr)
 		name := kv.Key.(*ast.Ident).Name
-		if idx := lookupField(t, name); idx >= 0 {
+		idx := lookupField(t, name)
+		if idx >= 0 {
 			ctx.cb.Val(idx)
 		} else {
 			log.Panicln("TODO: struct member not found -", name)
 		}
-		compileExpr(ctx, kv.Value)
+		switch expr := kv.Value.(type) {
+		case *ast.LambdaExpr, *ast.LambdaExpr2:
+			sig := checkLambdaFuncType(ctx, expr, t.Field(idx).Type(), clLambaField, kv.Key)
+			compileLambda(ctx, expr, sig)
+		default:
+			compileExpr(ctx, kv.Value)
+		}
 	}
 	ctx.cb.StructLit(typ, len(elts)<<1, true)
 }
